==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/mobilenetwork/kotlin/inputs/GetSlicePlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.mobilenetwork.kotlin.inputs

import com.pulumi.azurenative.mobilenetwork.inputs.GetSlicePlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property mobileNetworkName The name of the mobile network.
 * @property resourceGroupName The name of the resource group. The name is case insensitive.
 * @property sliceName The name of the network slice.
 */
public data class GetSlicePlainArgs(
    public val mobileNetworkName: String,
    public val resourceGroupName: String,
    public val sliceName: String,
) : ConvertibleToJava<com.pulumi.azurenative.mobilenetwork.inputs.GetSlicePlainArgs> {
    override fun toJava(): com.pulumi.azurenative.mobilenetwork.inputs.GetSlicePlainArgs =
        com.pulumi.azurenative.mobilenetwork.inputs.GetSlicePlainArgs.builder()
            .mobileNetworkName(mobileNetworkName.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 }))
            .sliceName(sliceName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetSlicePlainArgs].
 */
@PulumiTagMarker
public class GetSlicePlainArgsBuilder internal constructor() {
    private var mobileNetworkName: String? = null

    private var resourceGroupName: String? = null

    private var sliceName: String? = null

    /**
     * @param value The name of the mobile network.
     */
    @JvmName("nuagcrrqvhocookc")
    public suspend fun mobileNetworkName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.mobileNetworkName = mapped
    }

    /**
     * @param value The name of the resource group. The name is case insensitive.
     */
    @JvmName("vsjstpeaogcrnysv")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    /**
     * @param value The name of the network slice.
     */
    @JvmName("aqwavobmxchtunlt")
    public suspend fun sliceName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.sliceName = mapped
    }

    internal fun build(): GetSlicePlainArgs = GetSlicePlainArgs(
        mobileNetworkName = mobileNetworkName ?: throw PulumiNullFieldException("mobileNetworkName"),
        resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
        sliceName = sliceName ?: throw PulumiNullFieldException("sliceName"),
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/mobilenetwork/kotlin/inputs/GetSlicePlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.mobilenetwork.kotlin.inputs

import com.pulumi.azurenative.mobilenetwork.inputs.GetSlicePlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property mobileNetworkName The name of the mobile network.
 * @property resourceGroupName The name of the resource group. The name is case insensitive.
 * @property sliceName The name of the network slice.
 */
public data class GetSlicePlainArgs(
    public val mobileNetworkName: String,
    public val resourceGroupName: String,
    public val sliceName: String,
) : ConvertibleToJava<com.pulumi.azurenative.mobilenetwork.inputs.GetSlicePlainArgs> {
    override fun toJava(): com.pulumi.azurenative.mobilenetwork.inputs.GetSlicePlainArgs =
        com.pulumi.azurenative.mobilenetwork.inputs.GetSlicePlainArgs.builder()
            .mobileNetworkName(mobileNetworkName.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 }))
            .sliceName(sliceName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetSlicePlainArgs].
 */
@PulumiTagMarker
public class GetSlicePlainArgsBuilder internal constructor() {
    private var mobileNetworkName: String? = null

    private var resourceGroupName: String? = null

    private var sliceName: String? = null

    /**
     * @param value The name of the mobile network.
     */
    @JvmName("ulvueuyrmingdyfd")
    public suspend fun mobileNetworkName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.mobileNetworkName = mapped
    }

    /**
     * @param value The name of the resource group. The name is case insensitive.
     */
    @JvmName("tfwnubcrpuydjlxq")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    /**
     * @param value The name of the network slice.
     */
    @JvmName("xgfnarlbeliijcmn")
    public suspend fun sliceName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.sliceName = mapped
    }

    internal fun build(): GetSlicePlainArgs = GetSlicePlainArgs(
        mobileNetworkName = mobileNetworkName ?: throw PulumiNullFieldException("mobileNetworkName"),
        resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
        sliceName = sliceName ?: throw PulumiNullFieldException("sliceName"),
    )
}
